ams.opt.omodel
==============

.. automodule:: ams.opt.omodel

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      OModel
      OModelBase
   
   

   
   
   



